intelmq.bots.outputs.smtp package — intelmq 3.0.0.alpha.1 documentation

# intelmq.bots.outputs.smtp package

## Submodules

## intelmq.bots.outputs.smtp.output module

`intelmq.bots.outputs.smtp.output.` `BOT`

  alias of `intelmq.bots.outputs.smtp.output.SMTPOutputBot`

class `intelmq.bots.outputs.smtp.output.` `SMTPOutputBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  Send single events as CSV attachment in dynamically formatted e-mails via SMTP

  `fieldnames`: str = 'classification.taxonomy,classification.type,classification.identifier,source.ip,source.asn,source.port'
  `http_verify_cert`: Union[bool, str] = True
  `init`()
  `mail_from`: str = 'cert@localhost'
  `mail_to`: str = '{ev[source.abuse_contact]}'
  `process`()
  `smtp_host`: str = 'localhost'
  `smtp_password`: Optional[str] = None
  `smtp_port`: int = 25
  `smtp_username`: Optional[str] = None
  `ssl`: bool = False
  `starttls`: bool = True
  `subject`: str = 'Incident in your AS {ev[source.asn]}'
  `text`: str = 'Dear network owner,\\n\\nWe have been informed that the following device might have security problems.\\n\\nYour localhost CERT'

## Module contents